function main(varargin)

%%                 Initialization

errorInputs=[];
val=0;str=0;

%%                 General Parameters of GUI

windowWidth = 560;
windowHigh = 400;
buttonWidth = 70;
buttonHigh = 25;
textWidth = 150;
textHigh = 25;
editWidth = 80;
editHigh = 25;

gap = 10;

%%                 Figure

figureMain = figure(...
	'Name','Fiber Bridging 2.0',...
	'Tag','figureMain',...
    'NumberTitle','off',...
	'Units','pixels',...
    'Position',[0,0,windowWidth,windowHigh],...
    'MenuBar','none',...
    'Resize','off',...
	'Visible','off');

%%                 Panel Control

uipanelControl = uipanel(...
	'Tag','uipanelControl',...
	'Parent',figureMain,...
    'Title','Control',...
    'Units','pixels',...
    'Position',[gap gap 170 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

		listControl = uicontrol(...
			'Parent',uipanelControl,...
			'Style','listbox',...
			'Position',[gap 160 150 200],...
			'FontSize',10,...
			'BackgroundColor',[1 1 1],...
			'String',{'General','Fiber properties','Matrix properties','Interface properties','Other parameters','Computation','Results'},...
			'Callback',{@listControl_Callback});
		
		 textControl = uicontrol(...
			'Parent',uipanelControl,...
			'Style','text',...
			'Position',[gap 3*gap+3*buttonHigh textWidth textHigh*1.5],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','');

		pushDefault = uicontrol(...
			'Parent',uipanelControl,...
			'Style','pushbutton',...
			'Position',[gap gap*1.5+buttonHigh buttonWidth buttonHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'String','Default',...
			'Callback',{@pushDefault_Callback});

		pushComp = uicontrol(...
			'Parent',uipanelControl,...
			'Style','pushbutton',...
			'Position',[gap*2+buttonWidth gap*1.5+buttonHigh buttonWidth buttonHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'String','Computation',...
			'Callback',{@pushComp_Callback});

		pushLoad = uicontrol(...
			'Parent',uipanelControl,...
			'Style','pushbutton',...
			'Position',[gap gap buttonWidth buttonHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'String','Load',...
			'Callback',{@pushLoad_Callback});

		pushExit = uicontrol(...
			'Parent',uipanelControl,...
			'Style','pushbutton',...
			'Position',[gap*2+buttonWidth gap buttonWidth buttonHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'String','Exit',...
			'Callback',{@pushExit_Callback});

menuControl = [uipanelControl textControl listControl pushLoad pushDefault pushComp pushExit];

%%                 Panel general

uipanelGeneral = uipanel(...
	'Parent',figureMain,...
    'Title','General',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	% Panel Geometry
	uipanelGenGeo = uipanel(...
		'Parent',uipanelGeneral,...
		'Title','Geometry of specimen',...
		'Units','pixels',...
		'Position',[gap 255 340 105],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		% Check
		checkGenGeo = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','checkBox',...
			'Position',[gap 65 buttonWidth buttonHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'String','Auto',...
			'Value',1,...
			'Callback',{@checkGeneralGeometry_Callback});

		% Width
		 textGenGeoWidth = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','text',...
			'Position',[2*gap 35 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Width:');

		editGenGeoWidth = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 40 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Enable','off',...
			'Callback',{@edit_Callback});

		 textGenGeoWidthUnits = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 35 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','mm');

		% Thickness
		 textGenGeoThickness = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','text',...
			'Position',[2*gap 5 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Thickness:');

		editGenGeoThickness = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Enable','off',...
			'Callback',{@edit_Callback});

		 textGenGeoThicknessUnits = uicontrol(...
			'Parent',uipanelGenGeo,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','mm');

	% Panel Number
	uipanelGenNumber = uipanel(...
		'Parent',uipanelGeneral,...
		'Title','Number of cracks',...
		'Units','pixels',...
		'Position',[gap 200 340 55],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

			 textGenNumNum = uicontrol(...
				'Parent',uipanelGenNumber,...
				'Style','text',...
				'Position',[2*gap 5 textWidth textHigh],...
				'BackgroundColor',[0.8,0.8,0.8],...
				'HorizontalAlignment','left',...
				'String','Number:');

			editGenNumNum = uicontrol(...
				'Parent',uipanelGenNumber,...
				'Style','edit',...
				'Position',[2*gap+textWidth+gap 10 editWidth editHigh],...
				'BackgroundColor',[1,1,1],...
				'HorizontalAlignment','right',...
				...'String',1,...
				'Callback',{@edit_Callback});

menuGeneral = [uipanelGeneral uipanelGenGeo checkGenGeo...
	textGenGeoWidth editGenGeoWidth textGenGeoWidthUnits...
	textGenGeoThickness editGenGeoThickness textGenGeoThicknessUnits...
	uipanelGenNumber textGenNumNum editGenNumNum];

%%                 Panel Fiber properties

uipanelFiber = uipanel(...
	'Parent',figureMain,...
    'Title','Fiber properties',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	% Panel Geometry
	uipanelFibGeo = uipanel(...
		'Parent',uipanelFiber,...
		'Title','Geometry of fiber',...
		'Units','pixels',...
		'Position',[gap 275 340 85],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		% Length
		 textFibGeoLen = uicontrol(...
			'Parent',uipanelFibGeo,...
			'Style','text',...
			'Position',[2*gap 35 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Length:');

		editFibGeoLen = uicontrol(...
			'Parent',uipanelFibGeo,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 40 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textFibGeoLenUnits = uicontrol(...
			'Parent',uipanelFibGeo,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 35 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','mm');

		% Diameter
		 textFibGeoDia = uicontrol(...
			'Parent',uipanelFibGeo,...
			'Style','text',...
			'Position',[2*gap 5 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Diameter:');

		editFibGeoDia = uicontrol(...
			'Parent',uipanelFibGeo,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textFibGeoDiaUnits = uicontrol(...
			'Parent',uipanelFibGeo,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','mm');

	% Panel Volume fraction
	uipanelFibVol = uipanel(...
		'Parent',uipanelFiber,...
		'Title','Volume fraction',...
		'Units','pixels',...
		'Position',[gap 220 340 55],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		 textFibVol = uicontrol(...
			'Parent',uipanelFibVol,...
			'Position',[2*gap 5 textWidth textHigh],...
			'String','Volume fraction:',...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'Style','text');

		editFibVol = uicontrol(...
			'Parent',uipanelFibVol,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],... 
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textFibVolUnits = uicontrol(...
			'Parent',uipanelFibVol,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','[-]');

	% Panel Material
	uipanelFibMat = uipanel(...
		'Parent',uipanelFiber,...
		'Title','Material',...
		'Units','pixels',...
		'Position',[gap 135 340 85],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		% Modulus
		 textFibMatModulus = uicontrol(...
			'Parent',uipanelFibMat,...
			'Style','text',...
			'Position',[2*gap 35 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Modulus of elasticity:');

		editFibMatModulus = uicontrol(...
			'Parent',uipanelFibMat,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 40 editWidth editHigh],...	
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...					
			'Callback',{@edit_Callback});

		 textFibMatModulusUnits = uicontrol(...
			'Parent',uipanelFibMat,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 35 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','MPa');

		% Strength
		 textFibMatStrength = uicontrol(...
			'Parent',uipanelFibMat,...
			'Style','text',...
			'Position',[2*gap 5 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Strength:');

		editFibMatStrength = uicontrol(...
			'Parent',uipanelFibMat,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textFibMatStrengthUnits = uicontrol(...
			'Parent',uipanelFibMat,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','MPa');

menuFiber = [uipanelFiber uipanelFibGeo textFibGeoLen editFibGeoLen textFibGeoLenUnits...
	textFibGeoDia editFibGeoDia textFibGeoDiaUnits uipanelFibVol textFibVol editFibVol textFibVolUnits...
	uipanelFibMat textFibMatModulus editFibMatModulus textFibMatModulusUnits...
	textFibMatStrength editFibMatStrength textFibMatStrengthUnits];

%%                 Panel  Matrix properties

uipanelMatrix = uipanel(...
	'Parent',figureMain,...
    'Title','Matrix properties',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	% Panel Material
	uipanelMatMat = uipanel(...
		'Parent',uipanelMatrix,...
		'Title','Material',...
		'Units','pixels',...
		'Position',[gap 305 340 55],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		 textMatMat = uicontrol(...
			'Parent',uipanelMatMat,...
			'Style','text',...
			'Position',[2*gap 5 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Modulus of elasticity:');

		editMatMat= uicontrol(...
			'Parent',uipanelMatMat,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],... 
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textMatMatUnits = uicontrol(...
			'Parent',uipanelMatMat,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','MPa');

menuMatrix = [uipanelMatrix uipanelMatMat textMatMat editMatMat textMatMatUnits];

%%                 Panel Interface properties

uipanelInterface = uipanel(...
	'Parent',figureMain,...
    'Title','Interface properties',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	% Panel Material
	uipanelIntMat = uipanel(...
		'Parent',uipanelInterface,...
		'Title','Material',...
		'Units','pixels',...
		'Position',[gap 245 340 115],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		% Friction
		 textIntMatFrict = uicontrol(...
			'Parent',uipanelIntMat,...
			'Style','text',...
			'Position',[2*gap 65 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Friction:');

		editIntMatFrict = uicontrol(...
			'Parent',uipanelIntMat,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 70 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textIntMatFrictUnits = uicontrol(...
			'Parent',uipanelIntMat,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 65 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','MPa');

		% Chemical bond
		 textIntMatChem = uicontrol(...
			'Parent',uipanelIntMat,...
			'Style','text',...
			'Position',[2*gap 35 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Chemical bond:');

		editIntMatChem = uicontrol(...
			'Parent',uipanelIntMat,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 40 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textIntMatChemUnits = uicontrol(...
			'Parent',uipanelIntMat,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 35 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','N/m');

			% Slip-hardening parameter
			 textIntMatSHP = uicontrol(...
				'Parent',uipanelIntMat,...
				'Style','text',...
				'Position',[2*gap 5 textWidth textHigh],...
				'BackgroundColor',[0.8,0.8,0.8],...
				'HorizontalAlignment','left',...
				'String','Slip-hardening parameter:');

			editIntMatSHP = uicontrol(...
				'Parent',uipanelIntMat,...
				'Style','edit',...
				'Position',[2*gap+textWidth+gap 10 editWidth editHigh],...
				'BackgroundColor',[1,1,1],...
				'HorizontalAlignment','right',...
				'Callback',{@edit_Callback});

			 textIntMatSHPUnits = uicontrol(...
				'Parent',uipanelIntMat,...
				'Style','text',...
				'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
				'BackgroundColor',[0.8,0.8,0.8],...
				'HorizontalAlignment','left',...
				'String','[-]');

menuInterface = [uipanelInterface uipanelIntMat textIntMatSHP editIntMatSHP textIntMatSHPUnits...
	textIntMatChem editIntMatChem textIntMatChemUnits...
	textIntMatFrict editIntMatFrict textIntMatFrictUnits];

%%                 Panel Other parameters

uipanelOther = uipanel(...
	'Parent',figureMain,...
    'Title','Other parameters',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	% Panel Angle
	uipanelOthOth = uipanel(...
		'Parent',uipanelOther,...
		'Title','Effect of angle',...
		'Units','pixels',...
		'Position',[gap 245 340 115],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		% Snubbing coefficient
		 textOthOthSnu = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','text',...
			'Position',[2*gap 65 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Snubbing coefficient:');

		editOthOthSnu = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 70 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textOthOthSnuUnits = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 65 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','[-]');

		% Strength reduction coefficient
		 textOthOthSRC = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','text',...
			'Position',[2*gap 35 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Strength reduction coefficient:');

		editOthOthSRC = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 40 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textOthOthSRCUnits = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 35 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','[-]');

		% Strength reduction due to abrasion
		 textOthOthSRA = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','text',...
			'Position',[2*gap 5 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Strength reduction - abrasion:');

		editOthOthSRA = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],...
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			'Callback',{@edit_Callback});

		 textOthOthSRAUnits = uicontrol(...
			'Parent',uipanelOthOth,...
			'Style','text',...
			'Position',[2*gap+textWidth+gap+editWidth+gap 5 40 textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','[-]');

menuOther = [uipanelOther uipanelOthOth textOthOthSnu editOthOthSnu textOthOthSnuUnits...
	textOthOthSRC editOthOthSRC textOthOthSRCUnits textOthOthSRA editOthOthSRA textOthOthSRAUnits];

%%                 Panel  Computation parameters

uipanelComputation = uipanel(...
	'Parent',figureMain,...
    'Title','Computation',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	% Panel Computation parameters
	uipanelCompComp = uipanel(...
		'Parent',uipanelComputation,...
		'Title','Computation parameters',...
		'Units','pixels',...
		'Position',[gap 305 340 55],...
		'FontSize',8,...
		'BackgroundColor',[0.8,0.8,0.8]);

		 textCompComp = uicontrol(...
			'Parent',uipanelCompComp,...
			'Style','text',...
			'Position',[2*gap 5 textWidth textHigh],...
			'BackgroundColor',[0.8,0.8,0.8],...
			'HorizontalAlignment','left',...
			'String','Number of cores:');

		editCompComp= uicontrol(...
			'Parent',uipanelCompComp,...
			'Style','edit',...
			'Position',[2*gap+textWidth+gap 10 editWidth editHigh],... 
			'BackgroundColor',[1,1,1],...
			'HorizontalAlignment','right',...
			...'String',1,...
			'Callback',{@edit_Callback});

menuComputation = [uipanelComputation uipanelCompComp textCompComp editCompComp];

%%                 Panel  Results

uipanelResults = uipanel(...
	'Parent',figureMain,...
    'Title','Results',...
    'Units','pixels',...
    'Position',[gap*2+170 gap 360 windowHigh-2*gap],...
    'FontSize',8,...
    'BackgroundColor',[0.8,0.8,0.8]);

	axesResults = axes(...
		'Parent',uipanelResults,...
		'Units','pixels',...
		'Position',[45 115 285 240],...
		'FontSize',8,...
		'XGrid','on',...
		'YGrid','on');

	pushResTXT = uicontrol(...
		'Parent',uipanelResults,...
		'Style','pushbutton',...
		'Enable','off',...
		'Position',[gap gap*1.5+buttonHigh buttonWidth*2 buttonHigh],...
		'BackgroundColor',[0.8,0.8,0.8],...
		'String','Export to txt(s)',...
		'Callback',{@pushResTXT_Callback});

	pushResXLS = uicontrol(...
		'Parent',uipanelResults,...
		'Style','pushbutton',...
		'Enable','off',...
		'Position',[gap gap buttonWidth*2 buttonHigh],...
		'BackgroundColor',[0.8,0.8,0.8],...
		'String','Export to xls',...
		'Callback',{@pushResXLS_Callback});

menuResults = [uipanelResults axesResults pushResXLS pushResTXT];

%%

menuAll = [menuGeneral menuFiber menuMatrix menuInterface menuOther menuComputation menuResults];
editTexts = findobj('Style','edit');

%%                 Initialize the GUI

addpath(fullfile(pwd,'files'));
% addpath(fullfile(pwd,'input'));

setappdata(0,'handles_mainGui',gcf)
handles_mainGui = getappdata(0,'handles_mainGui');
setappdata(0,'textControl',textControl)

movegui(figureMain,'center')
set(menuControl,'Visible','on');
set(menuGeneral,'Visible','on');
set(setdiff(menuAll,menuGeneral),'Visible','off');
set(figureMain,'Visible','on');

xlabel(axesResults, 'Displacement [mm]')
ylabel(axesResults, 'Stress [MPa]')
check_edits()

%%                 Callback functions

% function name(hObject,eventdata)

function listControl_Callback(hObject,~)
str = get(hObject, 'String');
val = get(hObject, 'Value');
switch str{val}
	case 'General'
		menu =menuGeneral;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
	case 'Fiber properties'
		menu = menuFiber;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
	case 'Matrix properties'
		menu = menuMatrix;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
	case 'Interface properties'
		menu = menuInterface;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
	case 'Other parameters'
		menu = menuOther;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
	case 'Computation'
		menu = menuComputation;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
	case 'Results'
		menu = menuResults;
		set(menu,'Visible','on');
		set(setdiff(menuAll,menu),'Visible','off');
end
end

function pushComp_Callback(~,~)
	
	input.genSpecGeo = [get(checkGenGeo, 'Value'); 0];
	input.t = [str2double( get(editGenGeoThickness, 'String'))];
	input.b = [str2double( get(editGenGeoWidth, 'String'))];
	input.numCrack = [str2double( get(editGenNumNum, 'String'))];
	
	input.df = [str2double( get(editFibGeoDia, 'String')); 0];
	input.Lf = [str2double( get(editFibGeoLen, 'String')); 0];
	input.Ef = [str2double( get(editFibMatModulus, 'String')); 0];
	input.ftf = [str2double( get(editFibMatStrength, 'String')); 0];
	input.Vff = [str2double( get(editFibVol, 'String'))];

	input.Em = [str2double( get(editMatMat, 'String')); 0];

	input.tau0 = [str2double( get(editIntMatFrict, 'String')); 0];
	input.Gd = [str2double( get(editIntMatChem, 'String')); 0];
	input.beta = [str2double( get(editIntMatSHP, 'String')); 0];

	input.sc = [str2double( get(editOthOthSnu, 'String'))];
	input.src = [str2double( get(editOthOthSRC, 'String'))];
	input.sra = [str2double( get(editOthOthSRA, 'String'))];

	input.numCor = [str2double( get(editCompComp, 'String'))];
	
	cla(axesResults,'reset');
	grid on
	set(listControl,'Value',7);
	set(figureMain, 'Pointer','watch');
	listControl_Callback(listControl);
	pause(0.5);
	
	results = Program(input);
	set(figureMain, 'Pointer','arrow')
	
	linesColor = lines(input.numCrack);
	for i = 1:input.numCrack
		plot(axesResults, results(i).displacement, results(i).stress, 'LineWidth', 1, 'Color', linesColor(i, :)); hold on
	end
	hold off
	grid on
	xlabel(axesResults, 'Displacement [mm]')
	ylabel(axesResults, 'Stress [MPa]')
	
	set([pushResXLS pushResTXT],'enable','on');
	
	setappdata(handles_mainGui,'results',results);
end

function pushDefault_Callback(~,~)
	set(checkGenGeo, 'Value', 1);
	set([editGenGeoWidth editGenGeoThickness],'Enable','off');
	
	set(editGenGeoThickness, 'String', '');
	set(editGenGeoWidth, 'String', '');
	set(editGenNumNum, 'String', 1);
	
	set(editFibGeoDia, 'String', 0.04);
	set(editFibGeoLen, 'String', 12);
	set(editFibVol, 'String', 0.02);
	set(editFibMatStrength, 'String', 1600);
	set(editFibMatModulus, 'String', 21800);
	
	set(editMatMat, 'String', 15900);
	
	set(editIntMatSHP, 'String', 0);
	set(editIntMatChem, 'String', 0.004);
	set(editIntMatFrict, 'String', 2.21);
	
	set(editOthOthSRC, 'String', 0.3);
	set(editOthOthSnu, 'String', 0.5);
	set(editOthOthSRA, 'String', 1);
	
	set(editCompComp, 'String', 1);
	
	check_edits
end

function pushLoad_Callback(~,~)
	folder = [pwd]; % folder = [pwd filesep 'input'];

	[inFile, inPath] = uigetfile({'*.txt';'*.dat';'*.*'},'File Selector',folder);
 	
	if (inFile==0)
	else
		input = input_processing(inPath, inFile);
		set(checkGenGeo,'Value',input.genSpecGeo);
		if input.genSpecGeo == 0;
			set(editGenGeoThickness, 'String', input.t);
			set(editGenGeoWidth, 'String', input.b);
		end
		set(editGenNumNum, 'String', input.numCrack);

		set(editFibGeoDia, 'String', input.df);
		set(editFibGeoLen, 'String', input.Lf);
		set(editFibMatModulus, 'String', input.Ef);
		set(editFibMatStrength, 'String', input.ftf);
		set(editFibVol, 'String', input.Vff);

		set(editMatMat, 'String', input.Em);

		set(editIntMatFrict, 'String', input.tau0);
		set(editIntMatChem, 'String', input.Gd);
		set(editIntMatSHP, 'String', input.beta);

		set(editOthOthSnu, 'String', input.sc);
		set(editOthOthSRC, 'String', input.src);
		set(editOthOthSRA, 'String', input.sra);

		set(editCompComp, 'String', input.numCor);

		check_edits
	end
	
end

function pushResXLS_Callback(~,~)
	data = getappdata(handles_mainGui,'results');
	exportData = [];

	[inFile,inPath]=uiputfile({'*.xls','Xls Files (*.xls)';'*.dat','Data Files (*.dat)';'*.*','All Files (*.*)'},'Save as');
	
	if (inFile==0)
	else
		for i =1:size(data, 2)
			n = size(data(i).displacement, 1);
			exportData(1:n,1) = data(i).displacement;
			exportData(1:n,i+1) = data(i).stress;
		end
		
		xlswrite([inPath inFile],exportData);
	end
	
end

function pushResTXT_Callback(~,~)
	data = getappdata(handles_mainGui,'results');
	
	[inFile,inPath]=uiputfile({'*.txt','Text Files (*.txt)';'*.dat','Data Files (*.dat)';'*.*','All Files (*.*)'},'Save as');
	dotPosition = strfind(inFile, '.');
	
	if isempty(dotPosition)
		dotPosition = length(inFile)+1;
	end

	if (inFile==0)
	else
		for i =1:size(data, 2)
			exportData = [data(i).displacement data(i).stress];
			nameFile = [inFile(1:dotPosition-1) sprintf('%03.f', i) inFile(dotPosition:end)];
			save([inPath,nameFile],'exportData','-ascii');
		end
	end
end

function pushExit_Callback(~,~)
	close(figureMain)
end

function checkGeneralGeometry_Callback(hObject,~)
	val = get(hObject,'Value');
	if val == 1
		set([editGenGeoWidth editGenGeoThickness],'Enable','off');
		check_edits
	else
		set([editGenGeoWidth editGenGeoThickness],'Enable','on');
		check_edits
	end
end

function edit_Callback(hObject,~)
	% checks if the inputs are numbers
	string = get(hObject,'String');
	string = strrep(string, ',', '.');
	set(hObject,'String', string)
	
	userInput = str2double(string);
	
	if isnan(userInput)||userInput==1i||userInput==1j
		errordlg('You must enter a numerical value.','Error','modal')
	end
% 	check_edits
	if isnan(userInput)||userInput==1i||userInput==1j||size(strfind(get(hObject,'String'),','),2)>=1
		uicontrol(hObject)
		set(hObject,'BackgroundColor',[1,0,0]);
		if intersect(errorInputs,hObject)==hObject
		else
			errorInputs(end+1)=hObject;
		end
	else
		errorInputs=setdiff(errorInputs,hObject);
		set(hObject,'BackgroundColor',[1,1,1]);
	end
	
	if ~isempty(errorInputs)
		set(pushComp,'enable','off');
	else
		set(pushComp,'enable','on');
	end
end

function check_edits()
	errorInputs = intersect(findobj(editTexts, 'Enable' ,'on'), findobj(editTexts, 'String' ,''));
	set(errorInputs,'BackgroundColor',[1,0,0]);
	set(setdiff(editTexts, errorInputs), 'BackgroundColor',[1,1,1]);
	
	if ~isempty(errorInputs)
		set(pushComp,'enable','off');
	else
		set(pushComp,'enable','on');
	end
end

end